package com.raqsoft.spldemo;

import androidx.appcompat.app.AppCompatActivity;
import androidx.core.app.ActivityCompat;

import android.app.Activity;
import android.content.pm.PackageManager;
import android.os.Bundle;
import android.view.View;
import android.widget.EditText;

import com.raqsoft.app.common.AppUtil;
import com.raqsoft.app.config.ConfigUtil;
import com.raqsoft.dm.Env;

import java.io.File;
import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.ResultSetMetaData;
import java.util.ArrayList;

public class MainActivity extends AppCompatActivity {

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        verifyStoragePermissions( this );
        initSPL();
    }

    public static void verifyStoragePermissions(Activity activity) {
        try {
            String[] PERMISSIONS_STORAGE = new String[]{ "android.permission.WRITE_MEDIA_STORAGE",
                    "android.permission.READ_EXTERNAL_STORAGE",
                    "android.permission.WRITE_EXTERNAL_STORAGE" };
            int permission = ActivityCompat.checkSelfPermission( activity, "android.permission.WRITE_EXTERNAL_STORAGE");
            if( permission != PackageManager.PERMISSION_GRANTED ) {
                ActivityCompat.requestPermissions( activity, PERMISSIONS_STORAGE, 1 );
            }
        }
        catch( Exception e ) {
            e.printStackTrace();
        }
    }

    private void initSPL() {
        try {
            ConfigUtil.load("raqsoftConfig.xml");
            File dir = this.getExternalFilesDir(null);
            if (!dir.exists()) dir.mkdirs();
            Env.setMainPath(dir.getAbsolutePath());
        }
        catch( Throwable t ) {
            t.printStackTrace();
        }
    }

    public void calcLocalText(View view){
        EditText et = (EditText) findViewById( R.id.calcResult );
        String result = executeDfx( "calcLocalTxt", null );
        et.setText( result );
    }

    public void calcHttpJson(View view){
        EditText et = (EditText) findViewById( R.id.calcResult );
        ArrayList<Object> params = new ArrayList<Object>();
        params.add( new Integer( 1000 ) );
        String result = executeDfx( "calcHttpJson", params );
        et.setText( result );
    }

    private String executeDfx( String dfx, ArrayList<Object> params ) {
        try {
            Class.forName("com.esproc.jdbc.InternalDriver");
            Connection con = DriverManager.getConnection("jdbc:esproc:local://");
            int paramCount = 0;
            if( params != null ) paramCount = params.size();
            String script = "call " + dfx + "(";
            for( int i = 0; i < paramCount; i++ ) {
                if( i > 0 ) script += ",";
                script += "?";
            }
            script += ")";
            PreparedStatement st = con.prepareCall( script );
            for( int i = 0; i < paramCount; i++ ) {
                st.setObject( i + 1, params.get( i ) );
            }
            ResultSet rs = st.executeQuery();
            return resultSetToString( rs );
        }
        catch( Throwable t ) {
            return AppUtil.getThrowableString( t );
        }
    }

    private String resultSetToString( ResultSet rs ) throws Exception {
        StringBuffer sb = new StringBuffer();
        ResultSetMetaData rsmd = rs.getMetaData();
        int cols = rsmd.getColumnCount();
        for( int i = 1; i <= cols; i++ ) {
            if( i > 1 ) sb.append( "," );
            sb.append( rsmd.getColumnName( i ) );
        }
        sb.append( "\n" );
        while( rs.next() ) {
            for( int i = 1; i <= cols; i++ ) {
                if( i > 1 ) sb.append( "," );
                sb.append( rs.getString( i ) );
            }
            sb.append( "\n" );
        }
        return sb.toString();
    }

}
